@@ -28,12 +28,19 @@
 
 #include <glib/gutils.h>
 #include <glib/gfileutils.h>
+#include <glib/gunicode.h>
+
+#include "str.h"
 
 /* Data system and user data directories.  (must free w/ g_free()) */
-#define GL_SYSTEM_DATA_DIR g_build_filename (LIBGLABELS_TEMPLATE_DIR, NULL)
-#define GL_USER_DATA_DIR   g_build_filename (g_get_home_dir (), ".glabels", NULL)
+#define LGL_SYSTEM_DATA_DIR g_build_filename (LIBGLABELS_TEMPLATE_DIR, NULL)
+#define LGL_USER_DATA_DIR   g_build_filename (g_get_home_dir (), ".glabels", NULL)
 
 #undef  G_LOG_DOMAIN
 #define G_LOG_DOMAIN "LibGlabels"
 
+#define UTF8_EQUAL(s1,s2) (!lgl_str_utf8_casecmp (s1, s2))
+#define ASCII_EQUAL(s1,s2) (!g_ascii_strcasecmp (s1, s2))
+
+
 #endif /* __LIBGLABELS_PRIVATE_H__ */
