@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
+
 /*
  *  (GLABELS) Label and Business Card Creation program for GNOME
  *
@@ -52,15 +54,11 @@ enum {
 /* Private globals                           */
 /*===========================================*/
 
-static glMergeClass *parent_class = NULL;
-
 
 /*===========================================*/
 /* Local function prototypes                 */
 /*===========================================*/
 
-static void           gl_merge_text_class_init      (glMergeTextClass *klass);
-static void           gl_merge_text_instance_init   (glMergeText      *object);
 static void           gl_merge_text_finalize        (GObject          *object);
 
 static void           gl_merge_text_set_property    (GObject          *object,
@@ -83,47 +81,24 @@ static void           gl_merge_text_copy            (glMerge          *dst_merge
 
 static GList         *parse_line                    (FILE             *fp,
 						     gchar             delim);
+static gchar         *parse_field                   (gchar            *raw_field);
 static void           free_fields                   (GList           **fields);
 
 
 /*****************************************************************************/
 /* Boilerplate object stuff.                                                 */
 /*****************************************************************************/
-GType
-gl_merge_text_get_type (void)
-{
-	static GType type = 0;
-
-	if (!type) {
-		static const GTypeInfo info = {
-			sizeof (glMergeTextClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) gl_merge_text_class_init,
-			NULL,
-			NULL,
-			sizeof (glMergeText),
-			0,
-			(GInstanceInitFunc) gl_merge_text_instance_init,
-			NULL
-		};
-
-		type = g_type_register_static (GL_TYPE_MERGE,
-					       "glMergeText", &info, 0);
-	}
-
-	return type;
-}
+G_DEFINE_TYPE (glMergeText, gl_merge_text, GL_TYPE_MERGE);
 
 static void
-gl_merge_text_class_init (glMergeTextClass *klass)
+gl_merge_text_class_init (glMergeTextClass *class)
 {
-	GObjectClass *object_class = (GObjectClass *) klass;
-	glMergeClass *merge_class  = (glMergeClass *) klass;
+	GObjectClass *object_class = G_OBJECT_CLASS (class);
+	glMergeClass *merge_class  = GL_MERGE_CLASS (class);
 
 	gl_debug (DEBUG_MERGE, "START");
 
-	parent_class = g_type_class_peek_parent (klass);
+	gl_merge_text_parent_class = g_type_class_peek_parent (class);
 
 	object_class->set_property = gl_merge_text_set_property;
 	object_class->get_property = gl_merge_text_get_property;
@@ -148,11 +123,11 @@ gl_merge_text_class_init (glMergeTextClass *klass)
 }
 
 static void
-gl_merge_text_instance_init (glMergeText *merge_text)
+gl_merge_text_init (glMergeText *merge_text)
 {
 	gl_debug (DEBUG_MERGE, "START");
 
-	merge_text->private = g_new0 (glMergeTextPrivate, 1);
+	merge_text->priv = g_new0 (glMergeTextPrivate, 1);
 
 	gl_debug (DEBUG_MERGE, "END");
 }
@@ -160,11 +135,15 @@ gl_merge_text_instance_init (glMergeText *merge_text)
 static void
 gl_merge_text_finalize (GObject *object)
 {
+	glMergeText *merge_text = GL_MERGE_TEXT (object);
+
 	gl_debug (DEBUG_MERGE, "START");
 
 	g_return_if_fail (object && GL_IS_MERGE_TEXT (object));
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	g_free (merge_text->priv);
+
+	G_OBJECT_CLASS (gl_merge_text_parent_class)->finalize (object);
 
 	gl_debug (DEBUG_MERGE, "END");
 }
@@ -185,9 +164,9 @@ gl_merge_text_set_property (GObject      *object,
 	switch (param_id) {
 
 	case ARG_DELIM:
-		merge_text->private->delim = g_value_get_char (value);
+		merge_text->priv->delim = g_value_get_char (value);
 		gl_debug (DEBUG_MERGE, "ARG \"delim\" = \"%c\"",
-			  merge_text->private->delim);
+			  merge_text->priv->delim);
 		break;
 
         default:
@@ -214,7 +193,7 @@ gl_merge_text_get_property (GObject     *object,
 	switch (param_id) {
 
 	case ARG_DELIM:
-		g_value_set_char (value, merge_text->private->delim);
+		g_value_set_char (value, merge_text->priv->delim);
 		break;
 
         default:
@@ -291,7 +270,7 @@ gl_merge_text_open (glMerge *merge)
 	src = gl_merge_get_src (merge);
 
 	if (src != NULL) {
-		merge_text->private->fp = fopen (src, "r");
+		merge_text->priv->fp = fopen (src, "r");
 	}
 
 	g_free (src);
@@ -307,10 +286,10 @@ gl_merge_text_close (glMerge *merge)
 
 	merge_text = GL_MERGE_TEXT (merge);
 
-	if (merge_text->private->fp != NULL) {
+	if (merge_text->priv->fp != NULL) {
 
-		fclose (merge_text->private->fp);
-		merge_text->private->fp = NULL;
+		fclose (merge_text->priv->fp);
+		merge_text->priv->fp = NULL;
 
 	}
 }
@@ -331,8 +310,8 @@ gl_merge_text_get_record (glMerge *merge)
 
 	merge_text = GL_MERGE_TEXT (merge);
 
-	delim = merge_text->private->delim;
-	fp    = merge_text->private->fp;
+	delim = merge_text->priv->delim;
+	fp    = merge_text->priv->fp;
 
 	if (fp == NULL) {
 		return NULL;
@@ -376,11 +355,28 @@ gl_merge_text_copy (glMerge *dst_merge,
 	dst_merge_text = GL_MERGE_TEXT (dst_merge);
 	src_merge_text = GL_MERGE_TEXT (src_merge);
 
-	dst_merge_text->private->delim = src_merge_text->private->delim;
+	dst_merge_text->priv->delim = src_merge_text->priv->delim;
 }
 
 /*---------------------------------------------------------------------------*/
-/* PRIVATE.  Parse line (quoted values may span multiple lines).             */
+/* PRIVATE.  Parse line.                                                     */
+/*                                                                           */
+/* Attempt to be a robust parser of various CSV (and similar) formats.       */
+/*                                                                           */
+/* Split into fields, accounting for:                                        */
+/*   - delimeters may be embedded in quoted text (")                         */
+/*   - delimeters may be "escaped" by a leading backslash (\)                */
+/*   - quotes may be embedded in quoted text as two adjacent quotes ("")     */
+/*   - quotes may be "escaped" either within or outside of quoted text.      */
+/*   - newlines may be embedded in quoted text, allowing a field to span     */
+/*     more than one line.                                                   */
+/*                                                                           */
+/* This function does not do any parsing of the individual fields, other     */
+/* than to correctly interpet delimeters.  Actual parsing of the individual  */
+/* fields is done in parse_field().                                          */
+/*                                                                           */
+/* Returns a list of fields.  A blank line is considered a line with one     */
+/* empty field.  Returns empty (NULL) when done.                             */
 /*---------------------------------------------------------------------------*/
 static GList *
 parse_line (FILE  *fp,
@@ -389,9 +385,8 @@ parse_line (FILE  *fp,
 	GList *list = NULL;
 	GString *string;
 	gint c;
-	enum { BEGIN, NORMAL, NORMAL_ESCAPED,
-	       QUOTED, QUOTED_ESCAPED, QUOTED_QUOTE1,
-	       DONE } state;
+	enum { BEGIN, NORMAL, QUOTED, QUOTED_QUOTE1,
+               NORMAL_ESCAPED, QUOTED_ESCAPED, DONE } state;
 
 	state = BEGIN;
 	string = g_string_new( "" );
@@ -401,106 +396,80 @@ parse_line (FILE  *fp,
 		switch (state) {
 
 		case BEGIN:
+                        if ( c == delim )
+                        {
+                                /* first field is empty. */
+                                list = g_list_append (list, g_strdup (""));
+				state = NORMAL;
+                                break;
+                        }
 			switch (c) {
-			case '\\':
-				state = NORMAL_ESCAPED;
-				break;
 			case '"':
+                                string = g_string_append_c (string, c);
 				state = QUOTED;
 				break;
-			case '\r':
-				/* Strip CR. */
-				state = NORMAL;
+			case '\\':
+                                string = g_string_append_c (string, c);
+				state = NORMAL_ESCAPED;
 				break;
 			case '\n':
 				/* treat as one empty field. */
-				list = g_list_append (list,
-						      g_strdup (""));
+				list = g_list_append (list, g_strdup (""));
 				state = DONE;
 				break;
 			case EOF:
+                                /* end of file, no more lines. */
 				state = DONE;
 				break;
 			default:
-				if ( c != delim ) {
-					string = g_string_append_c (string, c);
-				} else {
-					list = g_list_append (list,
-						      g_strdup (string->str));
-					string = g_string_assign( string, "" );
-				}
+                                string = g_string_append_c (string, c);
 				state = NORMAL;
 				break;
 			}
 			break;
 
 		case NORMAL:
+                        if ( c == delim )
+                        {
+                                list = g_list_append (list, parse_field (string->str));
+                                string = g_string_assign( string, "" );
+                                state = NORMAL;
+                                break;
+                        }
 			switch (c) {
-			case '\\':
-				state = NORMAL_ESCAPED;
-				break;
 			case '"':
+                                string = g_string_append_c (string, c);
 				state = QUOTED;
 				break;
-			case '\r':
-				/* Strip CR. */
+			case '\\':
+                                string = g_string_append_c (string, c);
+				state = NORMAL_ESCAPED;
 				break;
 			case '\n':
 			case EOF:
-				list = g_list_append (list,
-						      g_strdup (string->str));
+				list = g_list_append (list, parse_field (string->str));
 				state = DONE;
 				break;
 			default:
-				if ( c != delim ) {
-					string = g_string_append_c (string, c);
-				} else {
-					list = g_list_append (list,
-						      g_strdup (string->str));
-					string = g_string_assign( string, "" );
-				}
-				break;
-			}
-			break;
-
-		case NORMAL_ESCAPED:
-			switch (c) {
-			case 'n':
-				string = g_string_append_c (string, '\n');
-				state = NORMAL;
-				break;
-			case 't':
-				string = g_string_append_c (string, '\t');
-				state = NORMAL;
-				break;
-			case '\r':
-				/* Strip CR, stay ESCAPED. */
-				break;
-			case EOF:
-				state = DONE;
-				break;
-			default:
-				string = g_string_append_c (string, c);
-				state = NORMAL;
+                                string = g_string_append_c (string, c);
+                                state = NORMAL;
 				break;
 			}
 			break;
 
 		case QUOTED:
 			switch (c) {
-			case '\\':
-				state = QUOTED_ESCAPED;
-				break;
 			case '"':
+                                string = g_string_append_c (string, c);
 				state = QUOTED_QUOTE1;
 				break;
-			case '\r':
-				/* Strip CR. */
+			case '\\':
+                                string = g_string_append_c (string, c);
+				state = QUOTED_ESCAPED;
 				break;
 			case EOF:
 				/* File ended mid way through quoted item */
-				list = g_list_append (list,
-						      g_strdup (string->str));
+				list = g_list_append (list, parse_field (string->str));
 				state = DONE;
 				break;
 			default:
@@ -509,63 +478,61 @@ parse_line (FILE  *fp,
 			}
 			break;
 
-		case QUOTED_ESCAPED:
-			switch (c) {
-			case 'n':
-				string = g_string_append_c (string, '\n');
-				state = QUOTED;
-				break;
-			case 't':
-				string = g_string_append_c (string, '\t');
-				state = QUOTED;
-				break;
-			case '\r':
-				/* Strip CR, stay ESCAPED. */
-				break;
-			case EOF:
-				/* File ended mid way through quoted item */
-				list = g_list_append (list,
-						      g_strdup (string->str));
-				state = DONE;
-				break;
-			default:
-				string = g_string_append_c (string, c);
-				state = QUOTED;
-				break;
-			}
-			break;
-
 		case QUOTED_QUOTE1:
+                        if ( c == delim )
+                        {
+                                list = g_list_append (list, parse_field (string->str));
+                                string = g_string_assign( string, "" );
+                                state = NORMAL;
+                                break;
+                        }
 			switch (c) {
 			case '"':
 				/* insert quotes in string, stay quoted. */
 				string = g_string_append_c (string, c);
 				state = QUOTED;
 				break;
-			case '\r':
-				/* Strip CR, return to NORMAL. */
-				state = NORMAL;
-				break;
 			case '\n':
 			case EOF:
 				/* line or file ended after quoted item */
-				list = g_list_append (list,
-						      g_strdup (string->str));
+				list = g_list_append (list, parse_field (string->str));
 				state = DONE;
 				break;
 			default:
-				if ( c != delim ) {
-					string = g_string_append_c (string, c);
-				} else {
-					list = g_list_append (list,
-						      g_strdup (string->str));
-					string = g_string_assign( string, "" );
-				}
+                                string = g_string_append_c (string, c);
 				state = NORMAL;
 				break;
 			}
 			break;
 
+		case NORMAL_ESCAPED:
+			switch (c) {
+			case EOF:
+				/* File ended mid way through quoted item */
+				list = g_list_append (list, parse_field (string->str));
+				state = DONE;
+				break;
+			default:
+				string = g_string_append_c (string, c);
+				state = NORMAL;
+				break;
+			}
+			break;
+
+		case QUOTED_ESCAPED:
+			switch (c) {
+			case EOF:
+				/* File ended mid way through quoted item */
+				list = g_list_append (list, parse_field (string->str));
+				state = DONE;
+				break;
+			default:
+				string = g_string_append_c (string, c);
+				state = QUOTED;
+				break;
+			}
+			break;
+
 		default:
 			g_assert_not_reached();
 			break;
@@ -577,6 +544,137 @@ parse_line (FILE  *fp,
 	return list;
 }
 
+/*---------------------------------------------------------------------------*/
+/* PRIVATE.  Parse field.                                                    */
+/*                                                                           */
+/*  - Strip leading and trailing white space, unless quoted.                 */
+/*  - Strip CR, unless escaped.                                              */
+/*  - Expand '\n' and '\t' into newline and tab characters.                  */
+/*  - Remove quotes, unless escaped (\" anywhere or "" within quotes)        */
+/*---------------------------------------------------------------------------*/
+static gchar *
+parse_field (gchar  *raw_field)
+{
+	GString *string;
+        gchar   *pass1_field, *c, *field;
+	enum { NORMAL, NORMAL_ESCAPED, QUOTED, QUOTED_ESCAPED, QUOTED_QUOTE1} state;
+
+
+        /*
+         * Pass 1: remove leading and trailing spaces.
+         */
+        pass1_field = g_strdup (raw_field);
+        g_strstrip (pass1_field);
+
+        /*
+         * Pass 2: resolve quoting and escaping.
+         */
+	state = NORMAL;
+	string = g_string_new( "" );
+        for ( c=pass1_field; *c != 0; c++ )
+        {
+		switch (state) {
+
+		case NORMAL:
+			switch (*c) {
+			case '\\':
+				state = NORMAL_ESCAPED;
+				break;
+			case '"':
+				state = QUOTED;
+				break;
+			case '\r':
+				/* Strip CR. */
+				break;
+			default:
+                                string = g_string_append_c (string, *c);
+				break;
+			}
+			break;
+
+		case NORMAL_ESCAPED:
+			switch (*c) {
+			case 'n':
+				string = g_string_append_c (string, '\n');
+				state = NORMAL;
+				break;
+			case 't':
+				string = g_string_append_c (string, '\t');
+				state = NORMAL;
+				break;
+			default:
+				string = g_string_append_c (string, *c);
+				state = NORMAL;
+				break;
+			}
+			break;
+
+		case QUOTED:
+			switch (*c) {
+			case '\\':
+				state = QUOTED_ESCAPED;
+				break;
+			case '"':
+				state = QUOTED_QUOTE1;
+				break;
+			case '\r':
+				/* Strip CR. */
+				break;
+			default:
+				string = g_string_append_c (string, *c);
+				break;
+			}
+			break;
+
+		case QUOTED_ESCAPED:
+			switch (*c) {
+			case 'n':
+				string = g_string_append_c (string, '\n');
+				state = QUOTED;
+				break;
+			case 't':
+				string = g_string_append_c (string, '\t');
+				state = QUOTED;
+				break;
+			default:
+				string = g_string_append_c (string, *c);
+				state = QUOTED;
+				break;
+			}
+			break;
+
+		case QUOTED_QUOTE1:
+			switch (*c) {
+			case '"':
+				/* insert quotes in string, stay quoted. */
+				string = g_string_append_c (string, *c);
+				state = QUOTED;
+				break;
+			case '\r':
+				/* Strip CR, return to QUOTED. */
+				state = QUOTED;
+				break;
+			default:
+                                string = g_string_append_c (string, *c);
+				state = NORMAL;
+				break;
+			}
+			break;
+
+		default:
+			g_assert_not_reached();
+			break;
+		}
+
+	}
+
+        field = g_strdup (string->str);
+	g_string_free( string, TRUE );
+        g_free (pass1_field);
+
+	return field;
+}
+
 /*---------------------------------------------------------------------------*/
 /* Free list of fields.                                                      */
 /*---------------------------------------------------------------------------*/
