@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
+
 /*
  *  (GLABELS) Label and Business Card Creation program for GNOME
  *
@@ -32,6 +34,7 @@
 #include "prefs.h"
 #include "mygal/widget-color-combo.h"
 #include "color.h"
+#include "util.h"
 
 #include "object-editor-private.h"
 
@@ -102,10 +105,10 @@ gl_object_editor_prepare_text_page (glObjectEditor       *editor)
 	gl_util_combo_box_add_text_model ( GTK_COMBO_BOX(editor->priv->text_color_key_combo));
 
 	/* Load family names */
-	family_names = gnome_font_family_list ();
+	family_names = gl_util_get_font_family_list ();
 	gl_util_combo_box_set_strings (GTK_COMBO_BOX(editor->priv->text_family_combo),
 				       family_names);
-	gnome_font_family_list_free (family_names);
+	gl_util_font_family_list_free (family_names);
 
 	/* Modify widgets */
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (editor->priv->text_color_radio), TRUE);
@@ -182,6 +185,8 @@ static void
 align_toggle_cb (GtkToggleButton *toggle,
 		 glObjectEditor  *editor)
 {
+        if (editor->priv->stop_signals) return;
+
         if (gtk_toggle_button_get_active (toggle)) {
  
                 if (GTK_WIDGET (toggle) == GTK_WIDGET (editor->priv->text_left_toggle)) {
@@ -227,12 +232,10 @@ gl_object_editor_set_font_family (glObjectEditor      *editor,
 
 	gl_debug (DEBUG_EDITOR, "START");
 
-	g_signal_handlers_block_by_func (G_OBJECT(editor->priv->text_family_combo),
-					 gl_object_editor_changed_cb,
-					 editor);
+        editor->priv->stop_signals = TRUE;
 
         /* Make sure we have a valid font family.  if not provide a good default. */
-        family_names = gnome_font_family_list ();
+        family_names = gl_util_get_font_family_list ();
         if (g_list_find_custom (family_names, font_family, (GCompareFunc)g_utf8_collate)) {
                 good_font_family = g_strdup (font_family);
         } else {
@@ -242,13 +245,11 @@ gl_object_editor_set_font_family (glObjectEditor      *editor,
                         good_font_family = NULL;
                 }
         }
-        gnome_font_family_list_free (family_names);
+        gl_util_font_family_list_free (family_names);
         gl_util_combo_box_set_active_text (GTK_COMBO_BOX (editor->priv->text_family_combo), good_font_family);
         g_free (good_font_family);
 
-	g_signal_handlers_unblock_by_func (G_OBJECT(editor->priv->text_family_combo),
-					   gl_object_editor_changed_cb,
-					   editor);
+        editor->priv->stop_signals = FALSE;
 
 	gl_debug (DEBUG_EDITOR, "END");
 }
@@ -279,16 +280,12 @@ gl_object_editor_set_font_size (glObjectEditor      *editor,
 {
 	gl_debug (DEBUG_EDITOR, "START");
 
-	g_signal_handlers_block_by_func (G_OBJECT(editor->priv->text_size_spin),
-					 gl_object_editor_changed_cb,
-					 editor);
+        editor->priv->stop_signals = TRUE;
 
         gtk_spin_button_set_value (GTK_SPIN_BUTTON (editor->priv->text_size_spin),
                                    font_size);
 
-	g_signal_handlers_unblock_by_func (G_OBJECT(editor->priv->text_size_spin),
-					   gl_object_editor_changed_cb,
-					   editor);
+        editor->priv->stop_signals = FALSE;
 
 	gl_debug (DEBUG_EDITOR, "END");
 }
@@ -316,20 +313,16 @@ gl_object_editor_get_font_size (glObjectEditor      *editor)
 /*****************************************************************************/
 void
 gl_object_editor_set_font_weight (glObjectEditor      *editor,
-				  GnomeFontWeight      font_weight)
+				  PangoWeight          font_weight)
 {
 	gl_debug (DEBUG_EDITOR, "START");
 
-	g_signal_handlers_block_by_func (G_OBJECT(editor->priv->text_bold_toggle),
-					 gl_object_editor_changed_cb,
-					 editor);
+        editor->priv->stop_signals = TRUE;
 
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (editor->priv->text_bold_toggle),
-                                      (font_weight == GNOME_FONT_BOLD));
+                                      (font_weight == PANGO_WEIGHT_BOLD));
 
-	g_signal_handlers_unblock_by_func (G_OBJECT(editor->priv->text_bold_toggle),
-					   gl_object_editor_changed_cb,
-					   editor);
+        editor->priv->stop_signals = FALSE;
 
 	gl_debug (DEBUG_EDITOR, "END");
 }
@@ -337,18 +330,18 @@ gl_object_editor_set_font_weight (glObjectEditor      *editor,
 /*****************************************************************************/
 /* Query font weight.                                                        */
 /*****************************************************************************/
-GnomeFontWeight
+PangoWeight
 gl_object_editor_get_font_weight (glObjectEditor      *editor)
 {
-	GnomeFontWeight font_weight;
+	PangoWeight font_weight;
 
 	gl_debug (DEBUG_EDITOR, "START");
 
         if (gtk_toggle_button_get_active
 	    (GTK_TOGGLE_BUTTON (editor->priv->text_bold_toggle))) {
-                font_weight = GNOME_FONT_BOLD;
+                font_weight = PANGO_WEIGHT_BOLD;
         } else {
-                font_weight = GNOME_FONT_BOOK;
+                font_weight = PANGO_WEIGHT_NORMAL;
         }
 
 	gl_debug (DEBUG_EDITOR, "END");
@@ -365,17 +358,12 @@ gl_object_editor_set_font_italic_flag (glObjectEditor      *editor,
 {
 	gl_debug (DEBUG_EDITOR, "START");
 
-	g_signal_handlers_block_by_func (G_OBJECT(editor->priv->text_italic_toggle),
-					 gl_object_editor_changed_cb,
-					 editor);
+        editor->priv->stop_signals = TRUE;
 
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (editor->priv->text_italic_toggle),
                                       font_italic_flag);
 
-
-	g_signal_handlers_unblock_by_func (G_OBJECT(editor->priv->text_italic_toggle),
-					   gl_object_editor_changed_cb,
-					   editor);
+        editor->priv->stop_signals = FALSE;
 
 	gl_debug (DEBUG_EDITOR, "END");
 }
@@ -404,36 +392,20 @@ gl_object_editor_get_font_italic_flag (glObjectEditor      *editor)
 /*****************************************************************************/
 void
 gl_object_editor_set_text_alignment (glObjectEditor      *editor,
-				     GtkJustification     just)
+				     PangoAlignment       align)
 {
 	gl_debug (DEBUG_EDITOR, "START");
 
-	g_signal_handlers_block_by_func (G_OBJECT(editor->priv->text_left_toggle),
-					 align_toggle_cb,
-					 editor);
-	g_signal_handlers_block_by_func (G_OBJECT(editor->priv->text_center_toggle),
-					 align_toggle_cb,
-					 editor);
-	g_signal_handlers_block_by_func (G_OBJECT(editor->priv->text_right_toggle),
-					 align_toggle_cb,
-					 editor);
+        editor->priv->stop_signals = TRUE;
 
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (editor->priv->text_left_toggle),
-                                      (just == GTK_JUSTIFY_LEFT));
+                                      (align == PANGO_ALIGN_LEFT));
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (editor->priv->text_center_toggle),
-                                      (just == GTK_JUSTIFY_CENTER));
+                                      (align == PANGO_ALIGN_CENTER));
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (editor->priv->text_right_toggle),
-                                      (just == GTK_JUSTIFY_RIGHT));
+                                      (align == PANGO_ALIGN_RIGHT));
 
-	g_signal_handlers_unblock_by_func (G_OBJECT(editor->priv->text_left_toggle),
-					   align_toggle_cb,
-					   editor);
-	g_signal_handlers_unblock_by_func (G_OBJECT(editor->priv->text_center_toggle),
-					   align_toggle_cb,
-					   editor);
-	g_signal_handlers_unblock_by_func (G_OBJECT(editor->priv->text_right_toggle),
-					   align_toggle_cb,
-					   editor);
+        editor->priv->stop_signals = FALSE;
 
 	gl_debug (DEBUG_EDITOR, "END");
 }
@@ -441,31 +413,31 @@ gl_object_editor_set_text_alignment (glObjectEditor      *editor,
 /*****************************************************************************/
 /* Query text alignment.                                                     */
 /*****************************************************************************/
-GtkJustification
+PangoAlignment
 gl_object_editor_get_text_alignment (glObjectEditor      *editor)
 {
-	GtkJustification just;
+	PangoAlignment align;
 
 	gl_debug (DEBUG_EDITOR, "START");
 
         if (gtk_toggle_button_get_active
             (GTK_TOGGLE_BUTTON (editor->priv->text_left_toggle))) {
-                just = GTK_JUSTIFY_LEFT;
+                align = PANGO_ALIGN_LEFT;
         } else
             if (gtk_toggle_button_get_active
                 (GTK_TOGGLE_BUTTON (editor->priv->text_right_toggle))) {
-                just = GTK_JUSTIFY_RIGHT;
+                align = PANGO_ALIGN_RIGHT;
         } else
             if (gtk_toggle_button_get_active
                 (GTK_TOGGLE_BUTTON (editor->priv->text_center_toggle))) {
-                just = GTK_JUSTIFY_CENTER;
+                align = PANGO_ALIGN_CENTER;
         } else {
-                just = GTK_JUSTIFY_LEFT;       /* Should not happen. */
+                align = PANGO_ALIGN_LEFT;       /* Should not happen. */
         }
 
 	gl_debug (DEBUG_EDITOR, "END");
 
-	return just;
+	return align;
 }
 
 /*****************************************************************************/
@@ -477,16 +449,10 @@ gl_object_editor_set_text_color (glObjectEditor      *editor,
 				 glColorNode         *text_color_node)
 {
 	GdkColor *gdk_color;
-	gint pos;
 
 	gl_debug (DEBUG_EDITOR, "START");
 
-	g_signal_handlers_block_by_func (G_OBJECT(editor->priv->text_color_combo),
-					 gl_object_editor_changed_cb,
-					 editor);
-	g_signal_handlers_block_by_func (G_OBJECT(editor->priv->text_color_key_combo),
-					 gl_object_editor_changed_cb,
-					 editor);
+        editor->priv->stop_signals = TRUE;
 
 	gl_debug (DEBUG_EDITOR, "color field %s(%d) / %X", text_color_node->key, text_color_node->field_flag, text_color_node->color);
 	
@@ -517,16 +483,11 @@ gl_object_editor_set_text_color (glObjectEditor      *editor,
 		gtk_widget_set_sensitive (editor->priv->text_color_key_combo, TRUE);
 		
 		gl_debug (DEBUG_EDITOR, "color field true 1");
-		gl_util_combo_box_set_active_text (GTK_COMBO_BOX (editor->priv->text_color_key_combo));
+		gl_util_combo_box_set_active_text (GTK_COMBO_BOX (editor->priv->text_color_key_combo), "");
 		gl_debug (DEBUG_EDITOR, "color field true 2");
 	}
 
-	g_signal_handlers_unblock_by_func (G_OBJECT(editor->priv->text_color_combo),
-					   gl_object_editor_changed_cb,
-					   editor);
-	g_signal_handlers_unblock_by_func (G_OBJECT(editor->priv->text_color_key_combo),
-					   gl_object_editor_changed_cb,
-					   editor);
+        editor->priv->stop_signals = FALSE;
 
 	gl_debug (DEBUG_EDITOR, "END");
 }
@@ -578,16 +539,12 @@ gl_object_editor_set_text_line_spacing (glObjectEditor      *editor,
 {
 	gl_debug (DEBUG_EDITOR, "START");
 
-	g_signal_handlers_block_by_func (G_OBJECT(editor->priv->text_line_spacing_spin),
-					 gl_object_editor_changed_cb,
-					 editor);
+        editor->priv->stop_signals = TRUE;
 
         gtk_spin_button_set_value (GTK_SPIN_BUTTON (editor->priv->text_line_spacing_spin),
                                    text_line_spacing);
 
-	g_signal_handlers_unblock_by_func (G_OBJECT(editor->priv->text_line_spacing_spin),
-					   gl_object_editor_changed_cb,
-					   editor);
+        editor->priv->stop_signals = FALSE;
 
 	gl_debug (DEBUG_EDITOR, "END");
 }
@@ -619,16 +576,12 @@ gl_object_editor_set_text_auto_shrink (glObjectEditor      *editor,
 {
 	gl_debug (DEBUG_EDITOR, "START");
 
-	g_signal_handlers_block_by_func (G_OBJECT(editor->priv->text_auto_shrink_check),
-					 gl_object_editor_changed_cb,
-					 editor);
+        editor->priv->stop_signals = TRUE;
 
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (editor->priv->text_auto_shrink_check),
                                       auto_shrink);
 
-	g_signal_handlers_unblock_by_func (G_OBJECT(editor->priv->text_auto_shrink_check),
-					   gl_object_editor_changed_cb,
-					   editor);
+        editor->priv->stop_signals = FALSE;
 
 	gl_debug (DEBUG_EDITOR, "END");
 }
@@ -656,12 +609,14 @@ gboolean    gl_object_editor_get_text_auto_shrink (glObjectEditor      *editor)
 static void
 text_radio_toggled_cb (glObjectEditor *editor)
 {
-    gl_debug (DEBUG_EDITOR, "START");
+        if (editor->priv->stop_signals) return;
+
+        gl_debug (DEBUG_EDITOR, "START");
 	
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (editor->priv->text_color_radio))) {
                 gtk_widget_set_sensitive (editor->priv->text_color_combo, TRUE);
                 gtk_widget_set_sensitive (editor->priv->text_color_key_combo, FALSE);
-    } else {
+        } else {
                 gtk_widget_set_sensitive (editor->priv->text_color_combo, FALSE);
                 gtk_widget_set_sensitive (editor->priv->text_color_key_combo, TRUE);
 		
