@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
 
 /**
  *  (GLABELS) Label and Business Card Creation program for GNOME
@@ -39,6 +39,7 @@
 #include "color.h"
 #include "wdgt-chain-button.h"
 #include "marshal.h"
+#include "util.h"
 
 #include "object-editor-private.h"
 
@@ -60,62 +61,36 @@ typedef void (*ChangedSignal) (GObject * object, gpointer data);
 
 gint gl_object_editor_signals[LAST_SIGNAL] = { 0 };
 
-static GtkVBoxClass *parent_class = NULL;
-
 /*===========================================*/
 /* Local function prototypes                 */
 /*===========================================*/
 
-static void gl_object_editor_class_init         (glObjectEditorClass  *klass);
-static void gl_object_editor_init               (glObjectEditor       *editor);
 static void gl_object_editor_finalize           (GObject              *object);
 
 static void gl_object_notebook_construct_valist (glObjectEditor       *editor,
+                                                 glLabel              *label,
 						 glObjectEditorOption  first_option,
 						 va_list               args);
 
 static void prefs_changed_cb                    (glObjectEditor       *editor);
 
+static void label_changed_cb                    (glLabel              *label,
+                                                 glObjectEditor       *editor);
+
 
 /*****************************************************************************/
 /* Boilerplate object stuff.                                                 */
 /*****************************************************************************/
-GType
-gl_object_editor_get_type (void)
-{
-	static GType type = 0;
-
-	if (!type)
-    	{
-      		static const GTypeInfo info =
-      		{
-			sizeof (glObjectEditorClass),
-        		NULL,		/* base_init */
-        		NULL,		/* base_finalize */
-        		(GClassInitFunc) gl_object_editor_class_init,
-        		NULL,           /* class_finalize */
-        		NULL,           /* class_data */
-        		sizeof (glObjectEditor),
-        		0,              /* n_preallocs */
-        		(GInstanceInitFunc) gl_object_editor_init,
-			NULL
-      		};
-
-     		type = g_type_register_static (GTK_TYPE_VBOX,
-					       "glObjectEditor", &info, 0);
-    	}
-
-	return type;
-}
+G_DEFINE_TYPE (glObjectEditor, gl_object_editor, GTK_TYPE_VBOX);
 
 static void
-gl_object_editor_class_init (glObjectEditorClass *klass)
+gl_object_editor_class_init (glObjectEditorClass *class)
 {
-	GObjectClass *object_class = G_OBJECT_CLASS (klass);
+	GObjectClass *object_class = G_OBJECT_CLASS (class);
 
 	gl_debug (DEBUG_EDITOR, "START");
 	
-  	parent_class = g_type_class_peek_parent (klass);
+  	gl_object_editor_parent_class = g_type_class_peek_parent (class);
 
   	object_class->finalize = gl_object_editor_finalize;  	
 
@@ -181,27 +156,23 @@ gl_object_editor_init (glObjectEditor *editor)
 static void 
 gl_object_editor_finalize (GObject *object)
 {
-	glObjectEditor* editor;
+	glObjectEditor* editor = GL_OBJECT_EDITOR (object);;
 	
 	gl_debug (DEBUG_EDITOR, "START");
 	
 	g_return_if_fail (object != NULL);
-	
-   	editor = GL_OBJECT_EDITOR (object);
-
 	g_return_if_fail (GL_IS_OBJECT_EDITOR (editor));
 	g_return_if_fail (editor->priv != NULL);
 
-	if (editor->priv->gui) {
-		g_object_unref (G_OBJECT (editor->priv->gui));
-	}
-
-	g_free (editor->priv);
-
 	g_signal_handlers_disconnect_by_func (G_OBJECT(gl_prefs),
 					      prefs_changed_cb, editor);
+	g_signal_handlers_disconnect_by_func (G_OBJECT(editor->priv->label),
+					      label_changed_cb, editor);
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+        g_object_unref (editor->priv->gui);
+	g_free (editor->priv);
+
+	G_OBJECT_CLASS (gl_object_editor_parent_class)->finalize (object);
 
 	gl_debug (DEBUG_EDITOR, "END");
 }
@@ -211,7 +182,8 @@ gl_object_editor_finalize (GObject *object)
 /*****************************************************************************/
 GtkWidget*
 gl_object_editor_new (gchar                *image,
-		      gchar                *label,
+		      gchar                *title,
+                      glLabel              *label,
 		      glObjectEditorOption  first_option, ...)
 {
 	glObjectEditor *editor;
@@ -227,11 +199,11 @@ gl_object_editor_new (gchar                *image,
 					  GTK_ICON_SIZE_LARGE_TOOLBAR);
 	}
 
-	if (label) {
+	if (title) {
 		gchar *s;
 
 		s = g_strdup_printf ("<span weight=\"bold\">%s</span>",
-				     label);
+				     title);
 		gtk_label_set_text (GTK_LABEL(editor->priv->title_label), s);
 		g_free (s);
 
@@ -242,7 +214,7 @@ gl_object_editor_new (gchar                *image,
 	gtk_notebook_set_homogeneous_tabs (GTK_NOTEBOOK(editor->priv->notebook), TRUE);
 
 	va_start (args, first_option);
-	gl_object_notebook_construct_valist (editor, first_option, args);
+	gl_object_notebook_construct_valist (editor, label, first_option, args);
 	va_end (args);
 
 	gl_debug (DEBUG_EDITOR, "END");
@@ -255,6 +227,7 @@ gl_object_editor_new (gchar                *image,
 /*--------------------------------------------------------------------------*/
 static void
 gl_object_notebook_construct_valist (glObjectEditor       *editor,
+                                     glLabel              *label,
 				     glObjectEditorOption  first_option,
 				     va_list               args)
 {
@@ -263,6 +236,8 @@ gl_object_notebook_construct_valist (glObjectEditor       *editor,
 
 	gl_debug (DEBUG_EDITOR, "START");
 
+        editor->priv->label = label;
+
 	option = first_option;
 
 	for ( option=first_option; option; option=va_arg (args, glObjectEditorOption) ) {
@@ -343,6 +318,16 @@ gl_object_notebook_construct_valist (glObjectEditor       *editor,
 	g_signal_connect_swapped (G_OBJECT (gl_prefs), "changed",
 				  G_CALLBACK (prefs_changed_cb),
 				  editor);
+        if (label)
+        {
+                label_changed_cb (label, editor);
+                g_signal_connect (G_OBJECT (label), "size_changed",
+                                  G_CALLBACK (label_changed_cb),
+                                  editor);
+                g_signal_connect (G_OBJECT (label), "merge_changed",
+                                  G_CALLBACK (label_changed_cb),
+                                  editor);
+        }
 
 	gl_debug (DEBUG_EDITOR, "END");
 }
@@ -353,6 +338,8 @@ gl_object_notebook_construct_valist (glObjectEditor       *editor,
 void
 gl_object_editor_changed_cb (glObjectEditor *editor)
 {
+        if (editor->priv->stop_signals) return;
+
 	gl_debug (DEBUG_EDITOR, "START");
 
 	/* Emit our "changed" signal */
@@ -367,6 +354,8 @@ gl_object_editor_changed_cb (glObjectEditor *editor)
 void
 gl_object_editor_size_changed_cb (glObjectEditor *editor)
 {
+        if (editor->priv->stop_signals) return;
+
 	gl_debug (DEBUG_EDITOR, "START");
 
 	/* Emit our "size_changed" signal */
@@ -675,3 +664,32 @@ prefs_changed_cb (glObjectEditor *editor)
 
 	gl_debug (DEBUG_EDITOR, "END");
 }
+
+/*---------------------------------------------------------------------------*/
+/* PRIVATE. label "changed" callback.                                        */
+/*---------------------------------------------------------------------------*/
+static void
+label_changed_cb (glLabel        *label,
+                  glObjectEditor *editor)
+{
+	gdouble   label_width, label_height;
+	glMerge	 *merge;
+
+	gl_debug (DEBUG_EDITOR, "START");
+
+	gl_label_get_size (label, &label_width, &label_height);
+	gl_object_editor_set_max_position (GL_OBJECT_EDITOR (editor),
+					   label_width, label_height);
+	gl_object_editor_set_max_size (GL_OBJECT_EDITOR (editor),
+				       label_width, label_height);
+	gl_object_editor_set_max_lsize (GL_OBJECT_EDITOR (editor),
+				       label_width, label_height);
+	gl_object_editor_set_max_shadow_offset (GL_OBJECT_EDITOR (editor),
+						label_width, label_height);
+	
+	merge = gl_label_get_merge (label);
+	gl_object_editor_set_key_names (editor, merge);
+
+	gl_debug (DEBUG_EDITOR, "END");
+}
+
