@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
+
 /*
  *  (GLABELS) Label and Business Card Creation program for GNOME
  *
@@ -23,9 +25,8 @@
 #define __PREFS_MODEL_H__
 
 #include <glib-object.h>
-#include <gtk/gtkenums.h>
 #include <gconf/gconf-client.h>
-#include <libgnomeprint/gnome-font.h>
+#include <pango/pango.h>
 #include <libglabels/enums.h>
 
 G_BEGIN_DECLS
@@ -56,7 +57,7 @@ struct _glPrefsModel {
 	GConfClient      *gconf_client;
 
 	/* Units */
-	glUnitsType       units;
+	lglUnitsType      units;
 
 	/* Page size */
 	gchar            *default_page_size;
@@ -64,10 +65,10 @@ struct _glPrefsModel {
 	/* Text properties */
 	gchar            *default_font_family;
 	gdouble           default_font_size;
-	GnomeFontWeight   default_font_weight;
+	PangoWeight       default_font_weight;
 	gboolean          default_font_italic_flag;
 	guint             default_text_color;
-	GtkJustification  default_text_alignment;
+	PangoAlignment    default_text_alignment;
 	gdouble           default_text_line_spacing;
 	
 	/* Line properties */
@@ -96,6 +97,10 @@ struct _glPrefsModel {
 
 	/* Recent files */
 	gint              max_recents;
+
+	/* Recent templates */
+        GSList           *recent_templates;
+	gint              max_recent_templates;
 };
 
 struct _glPrefsModelClass {
