@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
+
 /*
  *  (GLABELS) Label and Business Card Creation program for GNOME
  *
@@ -24,6 +26,7 @@
 #include "prefs.h"
 
 #include <glib/gi18n.h>
+#include <libglabels/libglabels.h>
 
 #include "debug.h"
 
@@ -78,7 +81,7 @@ gl_prefs_get_page_size (void)
 /****************************************************************************/
 /* Get desired units.                                                       */
 /****************************************************************************/
-glUnitsType
+lglUnitsType
 gl_prefs_get_units (void)
 {
 	return gl_prefs->units;
@@ -92,11 +95,11 @@ gl_prefs_get_units_per_point (void)
 {
 
 	switch (gl_prefs->units) {
-	case GL_UNITS_POINT:
+	case LGL_UNITS_POINT:
 		return 1.0;	/* points */
-	case GL_UNITS_INCH:
+	case LGL_UNITS_INCH:
 		return 1.0 / 72.0;	/* inches */
-	case GL_UNITS_MM:
+	case LGL_UNITS_MM:
 		return 0.35277778;	/* mm */
 	default:
 		g_message ("Illegal units");	/* Should not happen */
@@ -112,11 +115,11 @@ gl_prefs_get_units_precision (void)
 {
 
 	switch (gl_prefs->units) {
-	case GL_UNITS_POINT:
+	case LGL_UNITS_POINT:
 		return 1;	/* points */
-	case GL_UNITS_INCH:
+	case LGL_UNITS_INCH:
 		return 3;	/* inches */
-	case GL_UNITS_MM:
+	case LGL_UNITS_MM:
 		return 1;	/* mm */
 	default:
 		g_message ("Illegal units");	/* Should not happen */
@@ -132,11 +135,11 @@ gl_prefs_get_units_step_size (void)
 {
 
 	switch (gl_prefs->units) {
-	case GL_UNITS_POINT:
+	case LGL_UNITS_POINT:
 		return 0.1;	/* points */
-	case GL_UNITS_INCH:
+	case LGL_UNITS_INCH:
 		return 0.001;	/* inches */
-	case GL_UNITS_MM:
+	case LGL_UNITS_MM:
 		return 0.1;	/* mm */
 	default:
 		g_message ("Illegal units");	/* Should not happen */
@@ -152,11 +155,11 @@ gl_prefs_get_units_string (void)
 {
 
 	switch (gl_prefs->units) {
-	case GL_UNITS_POINT:
+	case LGL_UNITS_POINT:
 		return _("points");
-	case GL_UNITS_INCH:
+	case LGL_UNITS_INCH:
 		return _("inches");
-	case GL_UNITS_MM:
+	case LGL_UNITS_MM:
 		return _("mm");
 	default:
 		g_message ("Illegal units");	/* Should not happen */
@@ -164,3 +167,48 @@ gl_prefs_get_units_string (void)
 	}
 }
 
+/****************************************************************************/
+/* Add template to recent template list.                                    */
+/****************************************************************************/
+void
+gl_prefs_add_recent_template (const gchar *name)
+{
+        GSList *p;
+
+        /*
+         * If already in list, remove that entry.
+         */
+        p = g_slist_find_custom (gl_prefs->recent_templates,
+                                 name,
+                                 (GCompareFunc)lgl_str_utf8_casecmp);
+        if (p)
+        {
+                gl_prefs->recent_templates =
+                        g_slist_remove_link (gl_prefs->recent_templates, p);
+                g_free (p->data);
+                g_slist_free_1 (p);
+        }
+
+        /*
+         * Now prepend to list.
+         */
+        gl_prefs->recent_templates =
+                g_slist_prepend (gl_prefs->recent_templates, g_strdup (name));
+
+        /*
+         * Truncate list to maximum size
+         */
+        while (g_slist_length (gl_prefs->recent_templates) > gl_prefs->max_recent_templates)
+        {
+                p = g_slist_last (gl_prefs->recent_templates);
+                gl_prefs->recent_templates =
+                        g_slist_remove_link (gl_prefs->recent_templates, p);
+                g_free (p->data);
+                g_slist_free_1 (p);
+        }
+
+        /*
+         * Sync to disk.
+         */
+        gl_prefs_model_save_settings (gl_prefs);
+}
