@@ -30,23 +30,16 @@
 #include <gtk/gtkwindow.h>
 #include <gtk/gtkaboutdialog.h>
 #include <libgnome/gnome-help.h>
-#include <libgnome/gnome-url.h>
-#include "recent-files/egg-recent-view.h"
-#include "recent-files/egg-recent-view-uimanager.h"
 
 #include "view.h"
 #include "file.h"
 #include "template-designer.h"
-#include "print-dialog.h"
+#include "print-op.h"
 #include "prefs.h"
 #include "prefs-dialog.h"
 #include "recent.h"
 #include "debug.h"
 
-#define LOGO_PIXMAP gnome_program_locate_file (NULL,\
-                                         GNOME_FILE_DOMAIN_APP_PIXMAP,\
-                                         "glabels/glabels-about-logo.png",\
-                                         FALSE, NULL)
 
 
 /****************************************************************************/
@@ -125,26 +118,28 @@ gl_ui_cmd_file_open (GtkAction *action,
 /** File/Open-Recent command.                                               */
 /****************************************************************************/
 void 
-gl_ui_cmd_file_open_recent (GtkAction *action,
-                            glWindow  *window)
+gl_ui_cmd_file_open_recent (GtkRecentChooser *chooser,
+                            glWindow         *window)
 {
-        EggRecentViewUIManager *recent_view;
-        EggRecentItem          *item;
-        gchar                  *utf8_filename;
+        GtkRecentInfo *item;
+        gchar         *utf8_filename;
 
         gl_debug (DEBUG_COMMANDS, "START");
 
-        g_return_if_fail (action && GTK_IS_ACTION(action));
+        g_return_if_fail (chooser && GTK_IS_RECENT_CHOOSER(chooser));
         g_return_if_fail (window && GL_IS_WINDOW(window));
 
-        recent_view = g_object_get_data (G_OBJECT(window->ui), "recent-view");
-        g_return_if_fail (recent_view && EGG_IS_RECENT_VIEW_UIMANAGER (recent_view));
+        item = gtk_recent_chooser_get_current_item (chooser);
+        if (!item)
+                return;
 
-        item = egg_recent_view_uimanager_get_item (recent_view, action);
-        utf8_filename = gl_recent_get_filename (item);
+        utf8_filename = gl_recent_get_utf8_filename (item);
 
+        gl_debug (DEBUG_COMMANDS, "Selected %s\n", utf8_filename);
         gl_file_open_recent (utf8_filename, window);
 
+        gtk_recent_info_unref (item);
+        
         gl_debug (DEBUG_COMMANDS, "END");
 }
 
@@ -189,29 +184,30 @@ void
 gl_ui_cmd_file_print (GtkAction *action,
                       glWindow  *window)
 {
+        glPrintOp               *op;
+        GtkPrintOperationResult  result;
+
         gl_debug (DEBUG_COMMANDS, "START");
 
         g_return_if_fail (action && GTK_IS_ACTION(action));
         g_return_if_fail (window && GL_IS_WINDOW(window));
 
-        if (window->print_dialog) {
+        op = gl_print_op_new (GL_VIEW(window->view)->label);
 
-                gtk_window_present (GTK_WINDOW(window->print_dialog));
-                gtk_window_set_transient_for (GTK_WINDOW (window->print_dialog),
-                                              GTK_WINDOW (window));
+        if (window->print_settings)
+        {
+                gl_print_op_set_settings (op, window->print_settings);
+        }
 
-        } else {
+        result = gtk_print_operation_run (GTK_PRINT_OPERATION (op),
+                                          GTK_PRINT_OPERATION_ACTION_PRINT_DIALOG,
+                                          GTK_WINDOW (window),
+                                          NULL);
 
-                window->print_dialog =
-                        g_object_ref (
-                                gl_print_dialog_new (GL_VIEW(window->view)->label,
-                                                     GTK_WINDOW(window)) );
-
-                g_signal_connect (G_OBJECT(window->print_dialog), "destroy",
-                                  G_CALLBACK (gtk_widget_destroyed),
-                                  &window->print_dialog);
-
-                gtk_widget_show (GTK_WIDGET (window->print_dialog));
+        if ( result == GTK_PRINT_OPERATION_RESULT_APPLY )
+        {
+                gl_print_op_free_settings (window->print_settings);
+                window->print_settings = gl_print_op_get_settings (op);
         }
 
         gl_debug (DEBUG_COMMANDS, "END");
@@ -363,27 +359,27 @@ void
 gl_ui_cmd_edit_preferences (GtkAction *action,
                             glWindow  *window)
 {
-        static GtkWidget *dlg = NULL;
+        static GtkWidget *dialog = NULL;
 
         gl_debug (DEBUG_COMMANDS, "START");
 
         g_return_if_fail (action && GTK_IS_ACTION(action));
         g_return_if_fail (window && GL_IS_WINDOW(window));
 
-        if (dlg != NULL)
+        if (dialog != NULL)
         {
-                gtk_window_present (GTK_WINDOW (dlg));
-                gtk_window_set_transient_for (GTK_WINDOW (dlg),        
+                gtk_window_present (GTK_WINDOW (dialog));
+                gtk_window_set_transient_for (GTK_WINDOW (dialog),        
                                               GTK_WINDOW(window));
 
         } else {
                 
-                dlg = gl_prefs_dialog_new (GTK_WINDOW(window));
+                dialog = gl_prefs_dialog_new (GTK_WINDOW(window));
 
-                g_signal_connect (G_OBJECT (dlg), "destroy",
-                                  G_CALLBACK (gtk_widget_destroyed), &dlg);
+                g_signal_connect (G_OBJECT (dialog), "destroy",
+                                  G_CALLBACK (gtk_widget_destroyed), &dialog);
         
-                gtk_widget_show (dlg);
+                gtk_widget_show (dialog);
 
         }
 
@@ -1070,21 +1066,6 @@ gl_ui_cmd_help_contents (GtkAction *action,
         gl_debug (DEBUG_COMMANDS, "END");
 }
 
-/*--------------------------------------------------------------------------*/
-/** Private: URL handler.                                                   */
-/*--------------------------------------------------------------------------*/
-static void
-activate_url (GtkAboutDialog *about,
-              const gchar    *url,
-              gpointer        data)
-{
-        gl_debug (DEBUG_COMMANDS, "START");
-
-        gnome_url_show (url, NULL);
-
-        gl_debug (DEBUG_COMMANDS, "END");
-}
-
 
 /****************************************************************************/
 /** Help/About command.                                                     */
@@ -1117,7 +1098,7 @@ gl_ui_cmd_help_about (GtkAction *action,
                 NULL
         };
         
-        const gchar *copy_text = "Copyright \xc2\xa9 2001-2005 Jim Evins";
+        const gchar *copy_text = "Copyright \xc2\xa9 2001-2007 Jim Evins";
 
         const gchar *about_text = _("A label and business card creation program.\n");
 
@@ -1149,9 +1130,7 @@ gl_ui_cmd_help_about (GtkAction *action,
 
         } else {
         
-                pixbuf = gdk_pixbuf_new_from_file ( LOGO_PIXMAP, NULL);
-
-                gtk_about_dialog_set_url_hook (activate_url, NULL, NULL);
+                pixbuf = gdk_pixbuf_new_from_file (GLABELS_PIXMAP_DIR "glabels-splash.png", NULL);
 
                 about = gtk_about_dialog_new ();
                 gtk_about_dialog_set_name      (GTK_ABOUT_DIALOG(about), _("glabels"));
