@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
 
 /**
  *  (GLABELS) Label and Business Card Creation program for GNOME
@@ -32,7 +32,6 @@
 #include <gtk/gtkspinbutton.h>
 #include <gtk/gtktoolbar.h>
 #include <gtk/gtktoggletoolbutton.h>
-#include <libgnomeprint/gnome-font.h>
 #include <gtk/gtktooltips.h>
 #include <string.h>
 
@@ -44,13 +43,13 @@
 
 #include "debug.h"
 
-/*============================================================================*/
-/* Private macros and constants.                                              */
-/*============================================================================*/
+/*===========================================================================*/
+/* Private macros and constants.                                             */
+/*===========================================================================*/
 
-/*============================================================================*/
-/* Private data types                                                         */
-/*============================================================================*/
+/*===========================================================================*/
+/* Private data types                                                        */
+/*===========================================================================*/
 
 struct _glUIPropertyBarPrivate {
 
@@ -79,23 +78,19 @@ struct _glUIPropertyBarPrivate {
 	/* Line width */
 	GtkWidget  *line_width_spin;
 
+        /* Prevent recursion */
 	gboolean    stop_signals;
-
 };
 
 
-/*============================================================================*/
-/* Private globals                                                            */
-/*============================================================================*/
+/*===========================================================================*/
+/* Private globals                                                           */
+/*===========================================================================*/
 
-static GtkHBoxClass *parent_class;
+/*===========================================================================*/
+/* Local function prototypes                                                 */
+/*===========================================================================*/
 
-/*============================================================================*/
-/* Local function prototypes                                                  */
-/*============================================================================*/
-
-static void     gl_ui_property_bar_class_init    (glUIPropertyBarClass *class);
-static void     gl_ui_property_bar_instance_init (glUIPropertyBar      *property_bar);
 static void     gl_ui_property_bar_finalize      (GObject              *object);
 
 static void     gl_ui_property_bar_construct     (glUIPropertyBar      *property_bar);
@@ -160,40 +155,16 @@ static void     set_line_width_items_sensitive   (glUIPropertyBar      *property
 /****************************************************************************/
 /* Boilerplate Object stuff.                                                */
 /****************************************************************************/
-GType
-gl_ui_property_bar_get_type (void)
-{
-	static GType type = 0;
-
-	if (!type) {
-		static const GTypeInfo info = {
-			sizeof (glUIPropertyBarClass),
-			NULL,
-			NULL,
-			(GClassInitFunc) gl_ui_property_bar_class_init,
-			NULL,
-			NULL,
-			sizeof (glUIPropertyBar),
-			0,
-			(GInstanceInitFunc) gl_ui_property_bar_instance_init,
-			NULL
-		};
-
-		type = g_type_register_static (GTK_TYPE_HBOX,
-					       "glUIPropertyBar", &info, 0);
-	}
-
-	return type;
-}
+G_DEFINE_TYPE (glUIPropertyBar, gl_ui_property_bar, GTK_TYPE_HBOX);
 
 static void
 gl_ui_property_bar_class_init (glUIPropertyBarClass *class)
 {
-	GObjectClass   *object_class     = (GObjectClass *) class;
+	GObjectClass   *object_class     = G_OBJECT_CLASS (class);
 
 	gl_debug (DEBUG_PROPERTY_BAR, "START");
 
-	parent_class = g_type_class_peek_parent (class);
+	gl_ui_property_bar_parent_class = g_type_class_peek_parent (class);
 
 	object_class->finalize = gl_ui_property_bar_finalize;
 
@@ -201,44 +172,37 @@ gl_ui_property_bar_class_init (glUIPropertyBarClass *class)
 }
 
 static void
-gl_ui_property_bar_instance_init (glUIPropertyBar *property_bar)
+gl_ui_property_bar_init (glUIPropertyBar *property_bar)
 {
 	gl_debug (DEBUG_PROPERTY_BAR, "START");
 
 	property_bar->priv = g_new0 (glUIPropertyBarPrivate, 1);
 
-	property_bar->priv->gui = glade_xml_new (GLABELS_GLADE_DIR "property-bar.glade",
-						 "property_toolbar",
-						 NULL);
-
-	if (!property_bar->priv->gui) {
-		g_critical ("Could not open property-bar.glade. gLabels may not be installed correctly!");
-		return;
-	}
-
 	gl_debug (DEBUG_PROPERTY_BAR, "END");
 }
 
 static void
 gl_ui_property_bar_finalize (GObject *object)
 {
-	glUIPropertyBar *property_bar;
+	glUIPropertyBar *property_bar = GL_UI_PROPERTY_BAR (object);
 
 	gl_debug (DEBUG_PROPERTY_BAR, "START");
 
 	g_return_if_fail (object != NULL);
 	g_return_if_fail (GL_IS_UI_PROPERTY_BAR (object));
 
-	property_bar = GL_UI_PROPERTY_BAR (object);
-
-	if (property_bar->priv->view) {
+	if (property_bar->priv->view)
+        {
 		g_object_unref (G_OBJECT(property_bar->priv->view));
 	}
-
-	G_OBJECT_CLASS (parent_class)->finalize (object);
-
+        if (property_bar->priv->gui)
+        {
+                g_object_unref (G_OBJECT(property_bar->priv->gui));
+        }
 	g_free (property_bar->priv);
 
+	G_OBJECT_CLASS (gl_ui_property_bar_parent_class)->finalize (object);
+
 	gl_debug (DEBUG_PROPERTY_BAR, "END");
 }
 
@@ -267,6 +231,7 @@ gl_ui_property_bar_new (void)
 static void
 gl_ui_property_bar_construct (glUIPropertyBar   *property_bar)
 {
+	GladeXML   *gui;
 	GList      *family_names = NULL;
 	GList      *family_node;
 	GdkColor   *gdk_color;
@@ -275,38 +240,49 @@ gl_ui_property_bar_construct (glUIPropertyBar   *property_bar)
 
 	property_bar->priv->stop_signals = TRUE;
 
-	property_bar->priv->tool_bar = glade_xml_get_widget (property_bar->priv->gui,
-							     "property_toolbar");
+	gui = glade_xml_new (GLABELS_GLADE_DIR "property-bar.glade",
+                             "property_toolbar", NULL);
+
+	if (!gui)
+        {
+		g_critical ("Could not open property-bar.glade. gLabels may not be installed correctly!");
+		return;
+	}
+
+	property_bar->priv->tool_bar = glade_xml_get_widget (gui, "property_toolbar");
 	gtk_container_add (GTK_CONTAINER (property_bar), property_bar->priv->tool_bar);
 
 	property_bar->priv->font_family_combo =
-		glade_xml_get_widget (property_bar->priv->gui, "font_family_combo");
+		glade_xml_get_widget (gui, "font_family_combo");
 	property_bar->priv->font_size_spin =
-		glade_xml_get_widget (property_bar->priv->gui, "font_size_spin");
+		glade_xml_get_widget (gui, "font_size_spin");
 	property_bar->priv->font_bold_toggle =
-		glade_xml_get_widget (property_bar->priv->gui, "font_bold_toggle");
+		glade_xml_get_widget (gui, "font_bold_toggle");
 	property_bar->priv->font_italic_toggle =
-		glade_xml_get_widget (property_bar->priv->gui, "font_italic_toggle");
+		glade_xml_get_widget (gui, "font_italic_toggle");
 	property_bar->priv->text_align_left_radio =
-		glade_xml_get_widget (property_bar->priv->gui, "text_align_left_radio");
+		glade_xml_get_widget (gui, "text_align_left_radio");
 	property_bar->priv->text_align_center_radio =
-		glade_xml_get_widget (property_bar->priv->gui, "text_align_center_radio");
+		glade_xml_get_widget (gui, "text_align_center_radio");
 	property_bar->priv->text_align_right_radio =
-		glade_xml_get_widget (property_bar->priv->gui, "text_align_right_radio");
+		glade_xml_get_widget (gui, "text_align_right_radio");
 	property_bar->priv->text_color_combo =
-		glade_xml_get_widget (property_bar->priv->gui, "text_color_combo");
+		glade_xml_get_widget (gui, "text_color_combo");
 	property_bar->priv->fill_color_combo =
-		glade_xml_get_widget (property_bar->priv->gui, "fill_color_combo");
+		glade_xml_get_widget (gui, "fill_color_combo");
 	property_bar->priv->line_color_combo =
-		glade_xml_get_widget (property_bar->priv->gui, "line_color_combo");
+		glade_xml_get_widget (gui, "line_color_combo");
 	property_bar->priv->line_width_spin =
-		glade_xml_get_widget (property_bar->priv->gui, "line_width_spin");
+		glade_xml_get_widget (gui, "line_width_spin");
+
+        /* Save reference to gui tree so we don't lose tooltips */
+        property_bar->priv->gui = gui;
 
 	set_doc_items_sensitive (property_bar, FALSE);
 
 	/* Font family entry widget */
 	gl_util_combo_box_add_text_model (GTK_COMBO_BOX (property_bar->priv->font_family_combo));
-	family_names = gnome_font_family_list ();
+	family_names = gl_util_get_font_family_list ();
 	gl_util_combo_box_set_strings (GTK_COMBO_BOX (property_bar->priv->font_family_combo),
 				       family_names);
 	gtk_widget_set_size_request (property_bar->priv->font_family_combo, 200, -1);
@@ -315,14 +291,17 @@ gl_ui_property_bar_construct (glUIPropertyBar   *property_bar)
 	family_node = g_list_find_custom (family_names,
 					  gl_prefs->default_font_family,
 					  (GCompareFunc)g_utf8_collate);
-	if (family_node) {
+	if (family_node)
+        {
 		gtk_combo_box_set_active (GTK_COMBO_BOX (property_bar->priv->font_family_combo),
 					  g_list_position (family_names,
 							   family_node));
-	} else {
+	}
+        else
+        {
 		gtk_combo_box_set_active (GTK_COMBO_BOX (property_bar->priv->font_family_combo), 0);
 	}
-	gnome_font_family_list_free (family_names);
+	gl_util_font_family_list_free (family_names);
 
 	g_signal_connect (G_OBJECT (property_bar->priv->font_family_combo),
 			  "changed", G_CALLBACK (font_family_changed_cb), property_bar);
@@ -337,7 +316,7 @@ gl_ui_property_bar_construct (glUIPropertyBar   *property_bar)
 
 	/* Bold and Italic toggles */
 	gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON (property_bar->priv->font_bold_toggle),
-					   (gl_prefs->default_font_weight == GNOME_FONT_BOLD));
+					   (gl_prefs->default_font_weight == PANGO_WEIGHT_BOLD));
 	g_signal_connect (G_OBJECT (property_bar->priv->font_bold_toggle),
 			  "toggled", G_CALLBACK (font_bold_toggled_cb), property_bar);
 	gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON (property_bar->priv->font_italic_toggle),
@@ -348,15 +327,15 @@ gl_ui_property_bar_construct (glUIPropertyBar   *property_bar)
 
 	/* Text alignment radio group */
 	gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON (property_bar->priv->text_align_left_radio),
-					   (gl_prefs->default_text_alignment == GTK_JUSTIFY_LEFT));
+					   (gl_prefs->default_text_alignment == PANGO_ALIGN_LEFT));
 	g_signal_connect (G_OBJECT (property_bar->priv->text_align_left_radio),
 			  "toggled", G_CALLBACK (text_align_toggled_cb), property_bar);
 	gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON (property_bar->priv->text_align_center_radio),
-					   (gl_prefs->default_text_alignment == GTK_JUSTIFY_CENTER));
+					   (gl_prefs->default_text_alignment == PANGO_ALIGN_CENTER));
 	g_signal_connect (G_OBJECT (property_bar->priv->text_align_center_radio),
 			  "toggled", G_CALLBACK (text_align_toggled_cb), property_bar);
 	gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON (property_bar->priv->text_align_right_radio),
-					   (gl_prefs->default_text_alignment == GTK_JUSTIFY_RIGHT));
+					   (gl_prefs->default_text_alignment == PANGO_ALIGN_RIGHT));
 	g_signal_connect (G_OBJECT (property_bar->priv->text_align_right_radio),
 			  "toggled", G_CALLBACK (text_align_toggled_cb), property_bar);
 
@@ -406,37 +385,43 @@ reset_to_default_properties (glView *view,
 	GdkColor  *gdk_color;
 
 	/* Make sure we have a valid font.  if not provide a good default. */
-	family_names = gnome_font_family_list ();
+	family_names = gl_util_get_font_family_list ();
 	if (g_list_find_custom (family_names,
 				view->default_font_family,
-				(GCompareFunc)g_utf8_collate)) {
+				(GCompareFunc)g_utf8_collate))
+        {
 		good_font_family = g_strdup (view->default_font_family);
-	} else {
-		if (family_names != NULL) {
+	}
+        else
+        {
+		if (family_names != NULL)
+                {
 			good_font_family = g_strdup (family_names->data); /* 1st entry */
-		} else {
+		}
+                else
+                {
 			good_font_family = NULL;
 		}
 	}
 	gl_util_combo_box_set_active_text (GTK_COMBO_BOX (property_bar->priv->font_family_combo),
 					   good_font_family);
 	g_free (good_font_family);
-	gnome_font_family_list_free (family_names);
+	gl_util_font_family_list_free (family_names);
 
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON(property_bar->priv->font_size_spin),
 				   view->default_font_size);
 
 	gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON (property_bar->priv->font_bold_toggle),
-					   (view->default_font_weight == GNOME_FONT_BOLD));
+					   (view->default_font_weight == PANGO_WEIGHT_BOLD));
 	gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON (property_bar->priv->font_italic_toggle),
 					   view->default_font_italic_flag);
 
 	gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON (property_bar->priv->text_align_left_radio),
-					   (view->default_text_alignment == GTK_JUSTIFY_LEFT));
+					   (view->default_text_alignment == PANGO_ALIGN_LEFT));
 	gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON (property_bar->priv->text_align_center_radio),
-					   (view->default_text_alignment == GTK_JUSTIFY_CENTER));
+					   (view->default_text_alignment == PANGO_ALIGN_CENTER));
 	gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON (property_bar->priv->text_align_right_radio),
-					   (view->default_text_alignment == GTK_JUSTIFY_RIGHT));
+					   (view->default_text_alignment == PANGO_ALIGN_RIGHT));
 
 	gdk_color = gl_color_to_gdk_color (view->default_text_color);
 	color_combo_set_color (COLOR_COMBO(property_bar->priv->text_color_combo), gdk_color);
@@ -501,9 +486,12 @@ gl_ui_property_bar_set_tooltips (glUIPropertyBar *property_bar,
 	data = gtk_tooltips_data_get (property_bar->priv->font_size_spin);
 	g_return_if_fail (data);
 
-	if (state) {
+	if (state)
+        {
 		gtk_tooltips_enable (data->tooltips);
-	} else {
+	}
+        else
+        {
 		gtk_tooltips_disable (data->tooltips);
 	}
 
@@ -517,20 +505,20 @@ static void
 update_text_properties (glView *view,
 			glUIPropertyBar *property_bar)
 {
-	gboolean can_text, is_first_object;
-	gboolean is_same_font_family, is_same_font_size;
-	gboolean is_same_text_color, is_same_is_italic;
-	gboolean is_same_is_bold, is_same_justification;
-	GList *p;
-	glLabelObject *object;
-	gchar *selection_font_family, *font_family;
-	gdouble selection_font_size, font_size;
-	guint selection_text_color, text_color;
-	glColorNode *text_color_node;
-	gboolean selection_is_italic, is_italic;
-	gboolean selection_is_bold, is_bold;
-	GtkJustification selection_justification, justification;
-	GdkColor *gdk_color;
+	gboolean        can_text, is_first_object;
+	gboolean        is_same_font_family, is_same_font_size;
+	gboolean        is_same_text_color, is_same_is_italic;
+	gboolean        is_same_is_bold, is_same_align;
+	GList          *p;
+	glLabelObject  *object;
+	gchar          *selection_font_family, *font_family;
+	gdouble         selection_font_size, font_size;
+	guint           selection_text_color, text_color;
+	glColorNode    *text_color_node;
+	gboolean        selection_is_italic, is_italic;
+	gboolean        selection_is_bold, is_bold;
+	PangoAlignment  selection_align, align;
+	GdkColor       *gdk_color;
 
 	can_text = gl_view_can_selection_text (view);
 	set_text_items_sensitive (property_bar, can_text);
@@ -540,53 +528,72 @@ update_text_properties (glView *view,
 
 	is_same_is_italic =
 	is_same_is_bold =
-	is_same_justification =
+	is_same_align =
 	is_same_text_color =
 	is_same_font_size =
 	is_same_font_family = TRUE;
 	selection_font_family = NULL;
 	selection_font_size = -1;
+        selection_align = PANGO_ALIGN_LEFT;
+        selection_is_italic = TRUE;
+        selection_is_bold = TRUE;
+        selection_text_color = 0;
+        
 	is_first_object = TRUE;
 	
-	for (p = view->selected_object_list; p != NULL; p = p->next) {
+	for (p = view->selected_object_list; p != NULL; p = p->next)
+        {
 
 		object = gl_view_object_get_object(GL_VIEW_OBJECT (p->data));
 		if (!gl_label_object_can_text (object)) 
 			continue;
 
 		font_family = gl_label_object_get_font_family (object);
-		if (font_family != NULL) {
+		if (font_family != NULL)
+                {
 			if (selection_font_family == NULL)
+                        {
 				selection_font_family = g_strdup (font_family);
+                        }
 			else 
-				if (strcmp (font_family, selection_font_family) != 0) 
+                        {
+				if (strcmp (font_family, selection_font_family) != 0)
+                                {
 					is_same_font_family = FALSE;
+                                }
+                        }
 			g_free (font_family);
 		}	
 
 		font_size = gl_label_object_get_font_size (object);
 		
 		text_color_node = gl_label_object_get_text_color (object);
-		if (text_color_node->field_flag) {
+		if (text_color_node->field_flag)
+                {
 			/* If a merge field is set we use the default color for merged color*/
 			text_color = GL_COLOR_MERGE_DEFAULT;
 			
-		} else {
+		}
+                else
+                {
 			text_color = text_color_node->color;
 		}
 		gl_color_node_free (&text_color_node);
 		
 		is_italic = gl_label_object_get_font_italic_flag (object);
-		is_bold = gl_label_object_get_font_weight (object) == GNOME_FONT_BOLD;
-		justification = gl_label_object_get_text_alignment (object);
+		is_bold = gl_label_object_get_font_weight (object) == PANGO_WEIGHT_BOLD;
+		align = gl_label_object_get_text_alignment (object);
 
-		if (is_first_object) {
+		if (is_first_object)
+                {
 			selection_font_size = font_size;
 			selection_text_color = text_color;
 			selection_is_italic = is_italic;
 			selection_is_bold = is_bold;
-			selection_justification = justification;
-		} else {
+			selection_align = align;
+		}
+                else
+                {
 			if (font_size != selection_font_size) 
 				is_same_font_size = FALSE;
 			if (text_color != selection_text_color)
@@ -595,8 +602,8 @@ update_text_properties (glView *view,
 				is_same_is_italic = FALSE;
 			if (is_bold != selection_is_bold)
 				is_same_is_bold = FALSE;
-			if (justification != selection_justification)
-				is_same_justification = FALSE;
+			if (align != selection_align)
+				is_same_align = FALSE;
 		}
 		is_first_object = FALSE;
 	}
@@ -608,16 +615,20 @@ update_text_properties (glView *view,
 					   is_same_font_family?selection_font_family:"");
 	g_free (selection_font_family);
 
-	if (is_same_font_size) {
+	if (is_same_font_size)
+        {
 		gl_debug (DEBUG_PROPERTY_BAR, "same font size = %g", 
 			  selection_font_size);
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON (property_bar->priv->font_size_spin),
 					   selection_font_size);
-	} else {
+	}
+        else
+        {
 		gtk_entry_set_text (GTK_ENTRY (property_bar->priv->font_size_spin), "");
 	}
 
-	if (is_same_text_color) {
+	if (is_same_text_color)
+        {
 		gl_debug (DEBUG_PROPERTY_BAR, "same text color = %08x", selection_text_color);
 		gdk_color = gl_color_to_gdk_color (selection_text_color);
 		color_combo_set_color (COLOR_COMBO (property_bar->priv->text_color_combo),
@@ -625,29 +636,33 @@ update_text_properties (glView *view,
 		g_free (gdk_color);
 	}
 
-	if (is_same_is_italic)  
+	if (is_same_is_italic)
+        {
 		gl_debug (DEBUG_PROPERTY_BAR, "same italic flag = %d", 
 			  selection_is_italic);
+        }
 	gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON (property_bar->priv->font_italic_toggle),
 					   selection_is_italic && is_same_is_italic);
 
-	if (is_same_is_bold)  
+	if (is_same_is_bold)
+        {
 		gl_debug (DEBUG_PROPERTY_BAR, "same bold flag = %d",
 			  selection_is_bold);
+        }
 	gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON (property_bar->priv->font_bold_toggle),
 					   selection_is_bold && is_same_is_bold);
 
-	if (is_same_justification) 
-		gl_debug (DEBUG_PROPERTY_BAR, "same justification");
+	if (is_same_align) 
+		gl_debug (DEBUG_PROPERTY_BAR, "same align");
 	gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON (property_bar->priv->text_align_left_radio),
-					   (selection_justification == GTK_JUSTIFY_LEFT) &&
-					   is_same_justification);
+					   (selection_align == PANGO_ALIGN_LEFT) &&
+					   is_same_align);
 	gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON (property_bar->priv->text_align_center_radio),
-					   (selection_justification == GTK_JUSTIFY_CENTER) &&
-					   is_same_justification);
+					   (selection_align == PANGO_ALIGN_CENTER) &&
+					   is_same_align);
 	gtk_toggle_tool_button_set_active (GTK_TOGGLE_TOOL_BUTTON (property_bar->priv->text_align_right_radio),
-					   (selection_justification == GTK_JUSTIFY_RIGHT) &&
-					   is_same_justification);
+					   (selection_align == PANGO_ALIGN_RIGHT) &&
+					   is_same_align);
 }
 
 static void
@@ -670,33 +685,44 @@ update_fill_color (glView *view,
 
 	is_same_fill_color = TRUE;
 	is_first_object = TRUE;
+        selection_fill_color = 0;
 	
-	for (p = view->selected_object_list; p != NULL; p = p->next) {
+	for (p = view->selected_object_list; p != NULL; p = p->next)
+        {
 
 		object = gl_view_object_get_object(GL_VIEW_OBJECT (p->data));
 		if (!gl_label_object_can_fill (object)) 
 			continue;
 
 		fill_color_node = gl_label_object_get_fill_color (object);
-		if (fill_color_node->field_flag) {
+		if (fill_color_node->field_flag)
+                {
 			/* If a merge field is set we use the default color for merged color*/
 			fill_color = GL_COLOR_FILL_MERGE_DEFAULT;
 			
-		} else {
+		}
+                else
+                {
 			fill_color = fill_color_node->color;
 		}
 		gl_color_node_free (&fill_color_node);
 
-		if (is_first_object) {
+		if (is_first_object)
+                {
 			selection_fill_color = fill_color;
-		} else {
+		}
+                else
+                {
 			if (fill_color != selection_fill_color)
+                        {
 				is_same_fill_color = FALSE;
+                        }
 		}
 		is_first_object = FALSE;
 	}
 
-	if (is_same_fill_color) {
+	if (is_same_fill_color)
+        {
 		gl_debug (DEBUG_PROPERTY_BAR, "same fill color = %08x", selection_fill_color);
 		gdk_color = gl_color_to_gdk_color (selection_fill_color);
 		color_combo_set_color (COLOR_COMBO (property_bar->priv->fill_color_combo),
@@ -725,33 +751,44 @@ update_line_color (glView *view,
 
 	is_same_line_color = TRUE;
 	is_first_object = TRUE;
+        selection_line_color = 0;
 	
-	for (p = view->selected_object_list; p != NULL; p = p->next) {
+	for (p = view->selected_object_list; p != NULL; p = p->next)
+        {
 
 		object = gl_view_object_get_object(GL_VIEW_OBJECT (p->data));
 		if (!gl_label_object_can_line_color (object)) 
 			continue;
 
 		line_color_node = gl_label_object_get_line_color (object);
-		if (line_color_node->field_flag) {
+		if (line_color_node->field_flag)
+                {
 			/* If a merge field is set we use the default color for merged color*/
 			line_color = GL_COLOR_MERGE_DEFAULT;
 			
-		} else {
+		}
+                else
+                {
 			line_color = line_color_node->color;
 		}
 		gl_color_node_free (&line_color_node);
 
-		if (is_first_object) {
+		if (is_first_object)
+                {
 			selection_line_color = line_color;
-		} else {
+		}
+                else
+                {
 			if (line_color != selection_line_color)
+                        {
 				is_same_line_color = FALSE;
+                        }
 		}
 		is_first_object = FALSE;
 	}
 
-	if (is_same_line_color) {
+	if (is_same_line_color)
+        {
 		gl_debug (DEBUG_PROPERTY_BAR, "same line color = %08x", selection_line_color);
 		gdk_color = gl_color_to_gdk_color (selection_line_color);
 		color_combo_set_color (COLOR_COMBO (property_bar->priv->line_color_combo),
@@ -778,8 +815,10 @@ update_line_width (glView *view,
 
 	is_same_line_width = TRUE;
 	is_first_object = TRUE;
+        selection_line_width = 0;
 	
-	for (p = view->selected_object_list; p != NULL; p = p->next) {
+	for (p = view->selected_object_list; p != NULL; p = p->next)
+        {
 
 		object = gl_view_object_get_object(GL_VIEW_OBJECT (p->data));
 		if (!gl_label_object_can_line_width (object)) 
@@ -787,20 +826,28 @@ update_line_width (glView *view,
 
 		line_width = gl_label_object_get_line_width (object);
 
-		if (is_first_object) {
+		if (is_first_object)
+                {
 			selection_line_width = line_width;
-		} else {
+		}
+                else
+                {
 			if (line_width != selection_line_width)
+                        {
 				is_same_line_width = FALSE;
+                        }
 		}
 		is_first_object = FALSE;
 	}
 
-	if (is_same_line_width) {
+	if (is_same_line_width)
+        {
 		gl_debug (DEBUG_PROPERTY_BAR, "same line width = %g", selection_line_width);
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON (property_bar->priv->line_width_spin),
 					   selection_line_width);
-	} else {
+	}
+        else
+        {
 		gtk_entry_set_text (GTK_ENTRY (property_bar->priv->line_width_spin), "");
 	}
 }
@@ -810,31 +857,31 @@ selection_changed_cb (glUIPropertyBar *property_bar)
 {
 	glView *view = property_bar->priv->view;
 	
-	gl_debug (DEBUG_PROPERTY_BAR, "START");
-
 	g_return_if_fail (view && GL_IS_VIEW (view));
 	g_return_if_fail (property_bar && GL_IS_UI_PROPERTY_BAR (property_bar));
 
+	if (property_bar->priv->stop_signals) return;
 	property_bar->priv->stop_signals = TRUE;
 
-	if (gl_view_is_selection_empty (view)) {
+	gl_debug (DEBUG_PROPERTY_BAR, "START");
 
+	if (gl_view_is_selection_empty (view))
+        {
 		/* No selection: make all controls active. */
 		reset_to_default_properties (view, property_bar);
 		set_doc_items_sensitive (property_bar, TRUE);
-
-	} else {
-
+	}
+        else
+        {
 		update_text_properties (view, property_bar);
 		update_fill_color (view, property_bar);
 		update_line_color (view, property_bar);
 		update_line_width (view, property_bar);
-
 	}
 
-	property_bar->priv->stop_signals = FALSE;
-
 	gl_debug (DEBUG_PROPERTY_BAR, "END");
+
+	property_bar->priv->stop_signals = FALSE;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -846,17 +893,14 @@ font_family_changed_cb (GtkComboBox     *combo,
 {
 	gchar *font_family;
 
-	if (property_bar->priv->stop_signals)
-		return;
+	if (property_bar->priv->stop_signals) return;
+	property_bar->priv->stop_signals = TRUE;
 
 	gl_debug (DEBUG_PROPERTY_BAR, "START");
 
-	g_signal_handlers_block_by_func (G_OBJECT(property_bar->priv->view->label),
-					 selection_changed_cb,
-					 property_bar);
-
 	font_family = gtk_combo_box_get_active_text (GTK_COMBO_BOX (combo));
-	if ( strlen(font_family) ) {
+	if ( strlen(font_family) )
+        {
 		gl_view_set_selection_font_family (property_bar->priv->view,
 						   font_family);
 		gl_view_set_default_font_family   (property_bar->priv->view,
@@ -864,11 +908,9 @@ font_family_changed_cb (GtkComboBox     *combo,
 	}
 	g_free (font_family);
 
-	g_signal_handlers_unblock_by_func (G_OBJECT(property_bar->priv->view->label),
-					   selection_changed_cb,
-					   property_bar);
-
 	gl_debug (DEBUG_PROPERTY_BAR, "END");
+
+	property_bar->priv->stop_signals = FALSE;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -880,15 +922,11 @@ font_size_changed_cb (GtkSpinButton        *spin,
 {
 	gdouble font_size;
 
-	if (property_bar->priv->stop_signals)
-		return;
+	if (property_bar->priv->stop_signals) return;
+	property_bar->priv->stop_signals = TRUE;
 
 	gl_debug (DEBUG_PROPERTY_BAR, "START");
 
-	g_signal_handlers_block_by_func (G_OBJECT(property_bar->priv->view->label),
-					 selection_changed_cb,
-					 property_bar);
-
 	font_size = gtk_spin_button_get_value (spin);
 
 	gl_view_set_selection_font_size (property_bar->priv->view,
@@ -896,11 +934,9 @@ font_size_changed_cb (GtkSpinButton        *spin,
 	gl_view_set_default_font_size   (property_bar->priv->view,
 					 font_size);
 
-	g_signal_handlers_unblock_by_func (G_OBJECT(property_bar->priv->view->label),
-					   selection_changed_cb,
-					   property_bar);
-
 	gl_debug (DEBUG_PROPERTY_BAR, "END");
+
+	property_bar->priv->stop_signals = FALSE;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -916,16 +952,12 @@ text_color_changed_cb (ColorCombo           *cc,
 {
 	glColorNode *text_color_node;
 
-	if (property_bar->priv->stop_signals)
-		return;
-
 	g_return_if_fail (property_bar && GL_IS_UI_PROPERTY_BAR (property_bar));
 
-	gl_debug (DEBUG_PROPERTY_BAR, "START");
+	if (property_bar->priv->stop_signals) return;
+	property_bar->priv->stop_signals = TRUE;
 
-	g_signal_handlers_block_by_func (G_OBJECT(property_bar->priv->view->label),
-					 selection_changed_cb,
-					 property_bar);
+	gl_debug (DEBUG_PROPERTY_BAR, "START");
 
 	text_color_node = gl_color_node_new_default ();
 	text_color_node->color = gl_color_from_gdk_color (gdk_color);
@@ -933,29 +965,27 @@ text_color_changed_cb (ColorCombo           *cc,
 	gl_debug (DEBUG_PROPERTY_BAR, "Color=%08x, Custom=%d, By_User=%d, Is_default=%d",
 		  text_color_node->color, custom, by_user, is_default);
 
-	if (is_default) {
+	if (is_default)
+        {
 		text_color_node->color = gl_prefs->default_text_color;
 		gl_view_set_selection_text_color (property_bar->priv->view,
 						  text_color_node);
 		gl_view_set_default_text_color   (property_bar->priv->view,
 						  gl_prefs->default_text_color);
-
-	} else {
-
+	}
+        else
+        {
 		gl_view_set_selection_text_color (property_bar->priv->view,
 						  text_color_node);
 		gl_view_set_default_text_color   (property_bar->priv->view,
 						  text_color_node->color);
-
 	}
 
 	gl_color_node_free (&text_color_node);
 	
-	g_signal_handlers_unblock_by_func (G_OBJECT(property_bar->priv->view->label),
-					   selection_changed_cb,
-					   property_bar);
-
 	gl_debug (DEBUG_PROPERTY_BAR, "END");
+
+	property_bar->priv->stop_signals = FALSE;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -971,16 +1001,12 @@ fill_color_changed_cb (ColorCombo           *cc,
 {
 	glColorNode *fill_color_node;
 
-	if (property_bar->priv->stop_signals)
-		return;
-
 	g_return_if_fail (property_bar && GL_IS_UI_PROPERTY_BAR (property_bar));
 
-	gl_debug (DEBUG_PROPERTY_BAR, "START");
+	if (property_bar->priv->stop_signals) return;
+	property_bar->priv->stop_signals = TRUE;
 
-	g_signal_handlers_block_by_func (G_OBJECT(property_bar->priv->view->label),
-					 selection_changed_cb,
-					 property_bar);
+	gl_debug (DEBUG_PROPERTY_BAR, "START");
 
 	fill_color_node = gl_color_node_new_default ();
 
@@ -989,29 +1015,27 @@ fill_color_changed_cb (ColorCombo           *cc,
 	gl_debug (DEBUG_PROPERTY_BAR, "Color=%08x, Custom=%d, By_User=%d, Is_default=%d",
 		  fill_color_node->color, custom, by_user, is_default);
 
-	if (is_default) {
+	if (is_default)
+        {
 
 		fill_color_node->color = GL_COLOR_NONE;
 		gl_view_set_selection_fill_color (property_bar->priv->view,
 						  fill_color_node);
 		gl_view_set_default_fill_color   (property_bar->priv->view,
 						  fill_color_node->color);
-
-	} else {
-
+	}
+        else
+        {
 		gl_view_set_selection_fill_color (property_bar->priv->view,
 						  fill_color_node);
 		gl_view_set_default_fill_color   (property_bar->priv->view,
 						  fill_color_node->color);
-
 	}
 	gl_color_node_free (&fill_color_node);
 	
-	g_signal_handlers_unblock_by_func (G_OBJECT(property_bar->priv->view->label),
-					   selection_changed_cb,
-					   property_bar);
-
 	gl_debug (DEBUG_PROPERTY_BAR, "END");
+
+	property_bar->priv->stop_signals = FALSE;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -1027,16 +1051,12 @@ line_color_changed_cb (ColorCombo           *cc,
 {
 	glColorNode *line_color_node;
 
-	if (property_bar->priv->stop_signals)
-		return;
-
 	g_return_if_fail (property_bar && GL_IS_UI_PROPERTY_BAR (property_bar));
 
-	gl_debug (DEBUG_PROPERTY_BAR, "START");
+	if (property_bar->priv->stop_signals) return;
+	property_bar->priv->stop_signals = TRUE;
 
-	g_signal_handlers_block_by_func (G_OBJECT(property_bar->priv->view->label),
-					 selection_changed_cb,
-					 property_bar);
+	gl_debug (DEBUG_PROPERTY_BAR, "START");
 
 	line_color_node = gl_color_node_new_default ();
 	line_color_node->color = gl_color_from_gdk_color (gdk_color);
@@ -1044,28 +1064,26 @@ line_color_changed_cb (ColorCombo           *cc,
 	gl_debug (DEBUG_PROPERTY_BAR, "Color=%08x, Custom=%d, By_User=%d, Is_default=%d",
 		  line_color_node->color, custom, by_user, is_default);
 
-	if (is_default) {
+	if (is_default)
+        {
 		line_color_node->color = GL_COLOR_NONE;
 		gl_view_set_selection_line_color (property_bar->priv->view,
 						  line_color_node);
 		gl_view_set_default_line_color   (property_bar->priv->view,
 						  line_color_node->color);
-
-	} else {
-
+	}
+        else
+        {
 		gl_view_set_selection_line_color (property_bar->priv->view,
 						  line_color_node);
 		gl_view_set_default_line_color   (property_bar->priv->view,
 						  line_color_node->color);
-
 	}
 	gl_color_node_free (&line_color_node);
 
-	g_signal_handlers_unblock_by_func (G_OBJECT(property_bar->priv->view->label),
-					   selection_changed_cb,
-					   property_bar);
-
 	gl_debug (DEBUG_PROPERTY_BAR, "END");
+
+	property_bar->priv->stop_signals = FALSE;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -1077,31 +1095,24 @@ line_width_changed_cb (GtkSpinButton        *spin,
 {
 	gdouble line_width;
 
-	if (property_bar->priv->stop_signals)
-		return;
+	if (property_bar->priv->stop_signals) return;
+	property_bar->priv->stop_signals = TRUE;
 
 	gl_debug (DEBUG_PROPERTY_BAR, "START");
 
-	if (property_bar->priv->view) {
-
-		g_signal_handlers_block_by_func (G_OBJECT(property_bar->priv->view->label),
-						 selection_changed_cb,
-						 property_bar);
-
+	if (property_bar->priv->view)
+        {
 		line_width = gtk_spin_button_get_value (spin);
 
 		gl_view_set_selection_line_width (property_bar->priv->view,
 						  line_width);
 		gl_view_set_default_line_width   (property_bar->priv->view,
 						  line_width);
-
-		g_signal_handlers_unblock_by_func (G_OBJECT(property_bar->priv->view->label),
-						   selection_changed_cb,
-						   property_bar);
-
 	}
 
 	gl_debug (DEBUG_PROPERTY_BAR, "END");
+
+	property_bar->priv->stop_signals = FALSE;
 }
 
 /*---------------------------------------------------------------------------*/
@@ -1112,30 +1123,24 @@ font_bold_toggled_cb (GtkToggleToolButton  *toggle,
 		      glUIPropertyBar      *property_bar)
 {
 	gboolean        state;
-	GnomeFontWeight weight;
+	PangoWeight     weight;
 
 
-	if (property_bar->priv->stop_signals)
-		return;
+	if (property_bar->priv->stop_signals) return;
+	property_bar->priv->stop_signals = TRUE;
 
 	gl_debug (DEBUG_PROPERTY_BAR, "START");
 
-	g_signal_handlers_block_by_func (G_OBJECT(property_bar->priv->view->label),
-					 selection_changed_cb,
-					 property_bar);
-
 	state = gtk_toggle_tool_button_get_active (toggle);
 
-	weight = state ? GNOME_FONT_BOLD : GNOME_FONT_BOOK;
+	weight = state ? PANGO_WEIGHT_BOLD : PANGO_WEIGHT_NORMAL;
 
 	gl_view_set_selection_font_weight (property_bar->priv->view, weight);
 	gl_view_set_default_font_weight   (property_bar->priv->view, weight);
 
-	g_signal_handlers_unblock_by_func (G_OBJECT(property_bar->priv->view->label),
-					   selection_changed_cb,
-					   property_bar);
-
 	gl_debug (DEBUG_PROPERTY_BAR, "END");
+
+	property_bar->priv->stop_signals = FALSE;
 }
 						  
 /*---------------------------------------------------------------------------*/
@@ -1147,25 +1152,19 @@ font_italic_toggled_cb (GtkToggleToolButton  *toggle,
 {
 	gboolean state;
 
-	if (property_bar->priv->stop_signals)
-		return;
+	if (property_bar->priv->stop_signals) return;
+	property_bar->priv->stop_signals = TRUE;
 
 	gl_debug (DEBUG_PROPERTY_BAR, "START");
 
-	g_signal_handlers_block_by_func (G_OBJECT(property_bar->priv->view->label),
-					 selection_changed_cb,
-					 property_bar);
-
 	state = gtk_toggle_tool_button_get_active (toggle);
 
 	gl_view_set_selection_font_italic_flag (property_bar->priv->view, state);
 	gl_view_set_default_font_italic_flag   (property_bar->priv->view, state);
 
-	g_signal_handlers_unblock_by_func (G_OBJECT(property_bar->priv->view->label),
-					   selection_changed_cb,
-					   property_bar);
-
 	gl_debug (DEBUG_PROPERTY_BAR, "END");
+
+	property_bar->priv->stop_signals = FALSE;
 }
 						  
 /*---------------------------------------------------------------------------*/
@@ -1175,44 +1174,38 @@ static void
 text_align_toggled_cb (GtkToggleToolButton  *toggle,
 		       glUIPropertyBar      *property_bar)
 {
-	if (property_bar->priv->stop_signals)
-		return;
+	if (property_bar->priv->stop_signals) return;
+	property_bar->priv->stop_signals = TRUE;
 
 	gl_debug (DEBUG_PROPERTY_BAR, "START");
 
-	g_signal_handlers_block_by_func (G_OBJECT(property_bar->priv->view->label),
-					 selection_changed_cb,
-					 property_bar);
-
 	if (gtk_toggle_tool_button_get_active (GTK_TOGGLE_TOOL_BUTTON (property_bar->priv->text_align_left_radio)))
 	{		
 		gl_view_set_selection_text_alignment (property_bar->priv->view,
-						      GTK_JUSTIFY_LEFT);
+						      PANGO_ALIGN_LEFT);
 		gl_view_set_default_text_alignment   (property_bar->priv->view,
-						      GTK_JUSTIFY_LEFT);
+						      PANGO_ALIGN_LEFT);
 	}
 
 	if (gtk_toggle_tool_button_get_active (GTK_TOGGLE_TOOL_BUTTON (property_bar->priv->text_align_center_radio)))
 	{		
 		gl_view_set_selection_text_alignment (property_bar->priv->view,
-						      GTK_JUSTIFY_CENTER);
+						      PANGO_ALIGN_CENTER);
 		gl_view_set_default_text_alignment   (property_bar->priv->view,
-						      GTK_JUSTIFY_CENTER);
+						      PANGO_ALIGN_CENTER);
 	}
 
 	if (gtk_toggle_tool_button_get_active (GTK_TOGGLE_TOOL_BUTTON (property_bar->priv->text_align_right_radio)))
 	{
 		gl_view_set_selection_text_alignment (property_bar->priv->view,
-						      GTK_JUSTIFY_RIGHT);
+						      PANGO_ALIGN_RIGHT);
 		gl_view_set_default_text_alignment   (property_bar->priv->view,
-						      GTK_JUSTIFY_RIGHT);
+						      PANGO_ALIGN_RIGHT);
 	}
 
-	g_signal_handlers_unblock_by_func (G_OBJECT(property_bar->priv->view->label),
-					   selection_changed_cb,
-					   property_bar);
-
 	gl_debug (DEBUG_PROPERTY_BAR, "END");
+
+	property_bar->priv->stop_signals = FALSE;
 }
 
 
